source("plot_script.R")

project <- "warfarinPK_project.mlxtran"
cov_values <- list(
  wt = c(56, 126),
  sex = 1
)
ref_values <- data.frame(
  wt = 85,
  sex = 0
)
labels <- list(wt = "Weight",
               sex = "Sex",
               "56" = "56_kg",
               "126" = "126_kg",
               "1" = "Female")
replicates <- 1000

initializeLixoftConnectors("monolix", force = TRUE)
loadProject(project)
exportProject(settings = list(targetSoftware = "simulx"), force = TRUE)

setAddLines("ddt_AUC = Cc")
defineOutputElement(name = "AUC_24", element = list(
  data = data.frame(time = 24),
  output = "AUC"
))
defineTreatmentElement(name = "TRT", element = list(data = data.frame(
  time = 0,
  amount = 100
)))
setGroupElement("simulationGroup1", "mlx_TypicalUncertainSA")
setGroupElement("simulationGroup1", c("AUC_24", "mlx_Cc"))
setGroupElement("simulationGroup1", "TRT")
setGroupSize("simulationGroup1", 1)

defineCovariateElement(name = "ref", element = ref_values)
setGroupElement("simulationGroup1", "ref")
renameGroup("simulationGroup1", "Reference")

for (cov in names(cov_values)) {
  for (value in cov_values[[cov]]) {
    values <- ref_values
    values[[cov]] <- value
    element_name <- paste0(cov, "_", value)
    defineCovariateElement(name = element_name, element = values)

    group_name <- paste0(labels[cov], "_", labels[as.character(value)])
    addGroup(group_name)
    setGroupElement(group = group_name, elements = element_name)
  }
}
setNbReplicates(replicates)
runSimulation()

defineOutcome(name = "AUC", element = list(output = "AUC_24",
                                          processing = list(
                                            operator = "none"
                                          )))
defineOutcome(name = "Cmax", element = list(output = "mlx_Cc",
                                            processing = list(
                                              operator = "max",
                                              type = "value"
                                            )))
defineEndpoint("Endpoint_AUC", element = list(outcome = "AUC"))
defineEndpoint("Endpoint_Cmax", element = list(outcome = "Cmax"))
runEndpoints()
saveProject("script.smlx")

plotCovariateEffects(project = "script.smlx", outcome = "AUC")