source("plot_script.R")

project <- "warfarinPK_project.mlxtran"
replicates <- 1000

initializeLixoftConnectors("monolix", force = TRUE)
loadProject(project)
exportProject(settings = list(targetSoftware = "simulx"), force = TRUE)

setAddLines("ddt_AUC = Cc")
defineOutputElement(name = "AUC_24", element = list(
  data = data.frame(time = 24),
  output = "AUC"
))
defineTreatmentElement(name = "TRT", element = list(data = data.frame(
  time = 0,
  amount = 100
)))
setGroupElement("simulationGroup1", "mlx_PopUncertainSA")
setGroupElement("simulationGroup1", c("AUC_24", "mlx_Cc"))
setGroupElement("simulationGroup1", "TRT")
setGroupSize("simulationGroup1", 100)

defineCovariateElement(name = "Pediatric_cov", element = "pediatric_cov.csv")
setGroupElement("simulationGroup1", "Pediatric_cov")

setNbReplicates(replicates)
setSamplingMethod("withoutReplacement")
saveProject("script_2.smlx")
runSimulation()

defineOutcome(name = "AUC", element = list(output = "AUC_24",
                                          processing = list(
                                            operator = "none"
                                          )))
defineOutcome(name = "Cmax", element = list(output = "mlx_Cc",
                                            processing = list(
                                              operator = "max",
                                              type = "value"
                                            )))
defineEndpoint("Endpoint_AUC", element = list(outcome = "AUC"))
defineEndpoint("Endpoint_Cmax", element = list(outcome = "Cmax"))
saveProject()
runEndpoints()

plotIndividualExposure(
  project = "script_2.smlx",
  outcome = "AUC",
  cont_cov = "wt",
  nQuantiles = 4,
  labels = list(
    covariates = list(
      wt = "Weight",
      sex = "Sex"
    ),
    wt = list(
      "1" = "1st quartile",
      "2" = "2nd quartile",
      "3" = "3rd quartile",
      "4" = "4th quartile"
    ),
    sex = list(
      "0" = "Boys",
      "1" = "Girls"
    )
  )
)